from notion2md.client_store import notion_client_object
from notion2md.convertor.block import blocks_convertor
import os
import time
from notion2md.console import print_status

def block_exporter(config):
    start_time = time.time()
    #Directory Checking and Creating
    if not os.path.exists(config.output_path):
        os.mkdir(config.output_path)
    #Get actual blocks
    print()
    print_status("Retrieving",f"blocks from '{config.target_id}'")
    blocks = notion_client_object.blocks.children.list(config.target_id)['results']
    #Write(Export) Markdown file
    with open(os.path.join(config.output_path,config.file_name + '.md'),'w',encoding="utf-8") as output:
        output.write(blocks_convertor(blocks))
        
    #Result and Time Check
    print_status("Converted", f"{str(len(blocks))} blocks to markdown in {time.time() - start_time:.2f}s")
    print_status("Exported", f'"{config.file_name}.md" in "{os.path.abspath(config.output_path)}/"')
    print()

# page_exporter()

# database_exporter()



from notion_client.helpers import get_id
import notion2md
from notion2md.exporter import *
import os
import sys
import argparse
from notion2md.console import print_error, print_status

class Config(object):
    __slots__ = ("file_name", "target_id", "output_path","exporter_type")
    def __init__(self,id,name="",path="",url="",type=""):
        self.file_name = name if name else id

        self.output_path = os.path.abspath(path) if path \
        else os.path.join(os.getcwd(),'notion2md-output')

        self.target_id = get_id(url) if url else id

        if not self.target_id:
            print_error("please enter a Notion page's id or url")
            sys.exit(1)
        
        self.exporter_type = type

def parse_config() -> dict:
    parser = argparse.ArgumentParser(description="Notion2md: Notion Markdown Exporter with Python Cli")
    parser.add_argument('--type','-t',type=str,help="Set a type of target page: block, page, database",default="block")
    parser.add_argument('--url','-u',type=str,help="Set an url of target page")
    parser.add_argument('--id','-i',type=str,help="Set an id of target page")
    parser.add_argument('--path','-p',type=str,help="Set a relative path of output file")
    parser.add_argument('--name','-n',type=str,help="Set a custom name of output file")
    parser.add_argument('--version','-v', action='store_true',help="Show a version of Notion2Md")

    return vars(parser.parse_args())

def call_exporter(config:Config):
    target_type_map ={
        'block': block_exporter,
        # 'page': page_exporter,
        # 'database': database
    }

    target_type_map[config.exporter_type](config)
    
def run():
    args = parse_config()

    if args["version"]:
        print_status("Version", notion2md.__version__)
        sys.exit(None)
    else:
        del args["version"]

    config = Config(**args)
    
    call_exporter(config)


import os

os.system("")

class Style():
    BLACK = '\033[30m'
    RED = '\033[31m'
    GREEN = '\033[32m'
    YELLOW = '\033[33m'
    BLUE = '\033[34m'
    MAGENTA = '\033[35m'
    CYAN = '\033[36m'
    WHITE = '\033[37m'
    UNDERLINE = '\033[4m'
    BOLD = '\033[1m'
    RESET = '\033[0m'

def _formatted_print(left,right,error=False):
    color = Style.RED if error else Style.GREEN
    print(f"{color}{Style.BOLD}{left+' ':>12}{Style.RESET}{right}")
    

def print_error(message):
    print()
    _formatted_print("ERROR",message,error=True)
    print()

def print_status(status,message):
    _formatted_print(status,message)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['notion2md', 'notion2md.convertor']

package_data = \
{'': ['*']}

install_requires = \
['notion-client>=0.7.1']

entry_points = \
{'console_scripts': ['notion2md = notion2md.cli:run']}

setup_kwargs = {
    'name': 'notion2md',
    'version': '2.2.8',
    'description': 'Notion Markdown Exporter with Python Cli',
    'long_description': '![Notion2Md logo - an arrow pointing from "N" to "MD"](Notion2md.jpg)\n\n<br/>\n\n## About Notion2Md\n\n[![PyPI version](https://badge.fury.io/py/notion2md.svg)](https://badge.fury.io/py/notion2md)\n\n- Notion Markdown Exporter using **official notion api** by [notion-sdk-py](https://github.com/ramnes/notion-sdk-py)\n\n## API Key(Token)\n\n- Before getting started, create [an integration and find the token](https://www.notion.so/my-integrations). → [Learn more about authorization](https://developers.notion.com/docs/authorization).\n\n- Then save your api key(token) as your os environment variable\n\n```Bash\n$ export NOTION_TOKEN="{your integration token key}"\n```\n\n## Install\n\n```Bash\n$ pip install notion2md\n```\n\n## Useage: Shell Command\n\n![Terminal output of the `notion2md -h` command](notion2md_terminal.png)\n\n```Bash\nnotion2md -n post -p ~/MyBlog/content/posts -u https://notion.so/...\n```\n\n- This command will generate "**post.md**" in your \'**~/MyBlog/content/posts**\' directory\n\n## To-do\n\n- [ ] Page Exporter\n- [ ] Database Exporter\n- [ ] export file object(image and files)\n- [ ] export child page\n \n## Contribution\nPull requests are welcome. \n1. folk this repo into yours\n2. make changes and push to your repo\n3. send pull request from your **develop** branch to this develop branch\n\n**This is only way to give pull request to this repo. Thank you**\n\n## License\n[MIT](https://choosealicense.com/licenses/mit/)\n',
    'author': 'echo724',
    'author_email': 'eunchan1001@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/echo724/notion2md.git',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4',
}


setup(**setup_kwargs)
